#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module P2m
            class TransferNotificationRegistration < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'b58b7fee-95fc-42f0-b7ad-e67d3c01c7fc' => OperationConfig.new("/send/v1/partners/{partnerId}/notification-registries", "create", [], []),
                    '4752e3ed-e554-4c72-bfc2-82035dba69de' => OperationConfig.new("/send/v1/partners/{partnerId}/notification-registries/{account-reg-ref}", "delete", [], []),
                    '9e7e46f3-b69b-49eb-b8a7-1e70bb724975' => OperationConfig.new("/send/v1/partners/{partnerId}/notification-registries/{account-reg-ref}", "read", [], []),
                    '70f3aff4-7309-4e8c-ab8c-dbc42d9ace61' => OperationConfig.new("/send/v1/partners/{partnerId}/notification-registries/{account-reg-ref}", "update", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public


                def self.create(mapObj)
                    #
                    #Creates object of type TransferNotificationRegistration
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [TransferNotificationRegistration] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("b58b7fee-95fc-42f0-b7ad-e67d3c01c7fc", TransferNotificationRegistration.new(mapObj))
                end










                def self.deleteById(id, map = nil)
                    #Delete object of type TransferNotificationRegistration by id

                    #@param [String] id
                    #@param [Dict] map, containing additional parameters
                    #@return [TransferNotificationRegistration] of the response of the deleted instance.
                    #@raise [APIException] an exception from the response status


                    mapObj = TransferNotificationRegistration.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !map.nil?
                        if map.instance_of? RequestMap
                          mapObj.setAll(map.getObject())
                        else
                          mapObj.setAll(map)
                        end
                    end

                    return self.execute("4752e3ed-e554-4c72-bfc2-82035dba69de", mapObj)
                end


                def delete
                    #
                    #Delete object of type TransferNotificationRegistration

                    #@param [String] id
                    #@return [TransferNotificationRegistration] of the response of the deleted instance.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.class.execute("4752e3ed-e554-4c72-bfc2-82035dba69de", self)
                end








                def self.readby(id, criteria = nil)
                    #
                    #Returns objects of type TransferNotificationRegistration by id and optional criteria
                    #@param [String] id
                    #@param [Dict] criteria
                    #@return [TransferNotificationRegistration] object representing the response
                    #@raise [APIException] an exception from the response status

                    mapObj = TransferNotificationRegistration.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !criteria.nil?
                        if criteria.instance_of? RequestMap
                          mapObj.setAll(criteria.getObject())
                        else
                          mapObj.setAll(criteria)
                        end
                    end

                    return self.execute("9e7e46f3-b69b-49eb-b8a7-1e70bb724975",TransferNotificationRegistration.new(mapObj))
                end




                def update
                    #
                    #Updates an object of type TransferNotificationRegistration
                    #
                    #@return [TransferNotificationRegistration] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("70f3aff4-7309-4e8c-ab8c-dbc42d9ace61",self)
                end







            end
        end
    end
end







